#' Image annotation
#'
#' Image annotation using free drawing.
#'
#'
#' @name annotator
#' @docType package
#' @aliases annotator-package
#' @author Mihai Valcu \email{mvalcu@gwdg.de}
#'
#' @keywords internal
#' @import     methods utils
#' @import     shiny htmlwidgets
#' @importFrom xfun base64_uri
#'
"_PACKAGE"
